@@ -19,14 +19,10 @@
 
 #include "JobQueue.h"
 
-#include "Job.h"
-#include "GlobalStorage.h"
-#include "utils/Logger.h"
-
 #include "CalamaresConfig.h"
-#ifdef WITH_PYTHON
-#include "PythonHelper.h"
-#endif
+#include "GlobalStorage.h"
+#include "Job.h"
+#include "utils/Logger.h"
 
 #include <QThread>
 
@@ -40,14 +36,26 @@ public:
         : QThread( queue )
         , m_queue( queue )
         , m_jobIndex( 0 )
+        , m_jobCount( 0 )
     {
     }
 
     virtual ~JobThread() override;
 
-    void setJobs( const JobList& jobs )
+    void setJobs( JobList&& jobs )
     {
         m_jobs = jobs;
+
+        qreal totalJobsWeight = 0.0;
+        for ( auto job : m_jobs )
+        {
+            totalJobsWeight += job->getJobWeight();
+        }
+        for ( auto job : m_jobs )
+        {
+            qreal jobWeight = qreal( job->getJobWeight() / totalJobsWeight );
+            m_jobWeights.append( jobWeight );
+        }
     }
 
     void run() override
@@ -57,7 +65,7 @@ public:
         QString details;
 
         m_jobIndex = 0;
-        for( auto job : m_jobs )
+        for ( auto job : m_jobs )
         {
             if ( anyFailed && !job->isEmergency() )
             {
@@ -66,7 +74,7 @@ public:
             }
 
             emitProgress();
-            cDebug() << "Starting" << ( anyFailed ? "EMERGENCY JOB" : "job" ) << job->prettyName();
+            cDebug() << "Starting" << ( anyFailed ? "EMERGENCY JOB" : "job" ) << job->prettyName() << " (there are" << m_jobs.count() << " left)";
             connect( job.data(), &Job::progress, this, &JobThread::emitProgress );
             JobResult result = job->exec();
             if ( !anyFailed && !result )
@@ -76,19 +84,27 @@ public:
                 details = result.details();
             }
             if ( !anyFailed )
+            {
                 ++m_jobIndex;
+            }
         }
         if ( anyFailed )
+        {
             emitFailed( message, details );
+        }
         else
+        {
             emitProgress();
+        }
         emitFinished();
     }
 
 private:
     JobList m_jobs;
+    QList< qreal > m_jobWeights;
     JobQueue* m_queue;
     int m_jobIndex;
+    int m_jobCount;
 
     void emitProgress( qreal jobPercent = 0 )
     {
@@ -97,35 +113,39 @@ private:
         jobPercent = qBound( qreal( 0 ), jobPercent, qreal( 1 ) );
 
         int jobCount = m_jobs.size();
-        QString message = m_jobIndex < jobCount
-            ? m_jobs.at( m_jobIndex )->prettyStatusMessage()
-            : tr( "Done" );
+        QString message = m_jobIndex < jobCount ? m_jobs.at( m_jobIndex )->prettyStatusMessage() : tr( "Done" );
 
-        qreal percent = ( m_jobIndex + jobPercent ) / qreal( jobCount );
+        qreal cumulativeProgress = 0.0;
+        for ( auto jobWeight : m_jobWeights.mid( 0, m_jobIndex ) )
+        {
+            cumulativeProgress += jobWeight;
+        }
+        qreal percent
+            = m_jobIndex < jobCount ? cumulativeProgress + ( ( m_jobWeights.at( m_jobIndex ) ) * jobPercent ) : 1.0;
 
-        QMetaObject::invokeMethod( m_queue, "progress", Qt::QueuedConnection,
-            Q_ARG( qreal, percent ),
-            Q_ARG( QString, message )
-        );
+        if ( m_jobIndex < jobCount )
+        {
+            cDebug( Logger::LOGVERBOSE ) << "[JOBQUEUE]: Progress for Job[" << m_jobIndex
+                                         << "]: " << ( jobPercent * 100 ) << "% completed";
+            cDebug( Logger::LOGVERBOSE ) << "[JOBQUEUE]: Progress Overall: " << ( cumulativeProgress * 100 )
+                                         << "% (accumulated) + "
+                                         << ( ( ( m_jobWeights.at( m_jobIndex ) ) * jobPercent ) * 100 )
+                                         << "% (this job) = " << ( percent * 100 ) << "% (total)";
+        }
+        QMetaObject::invokeMethod(
+            m_queue, "progress", Qt::QueuedConnection, Q_ARG( qreal, percent ), Q_ARG( QString, message ) );
     }
 
     void emitFailed( const QString& message, const QString& details )
     {
-        QMetaObject::invokeMethod( m_queue, "failed", Qt::QueuedConnection,
-            Q_ARG( QString, message ),
-            Q_ARG( QString, details )
-        );
+        QMetaObject::invokeMethod(
+            m_queue, "failed", Qt::QueuedConnection, Q_ARG( QString, message ), Q_ARG( QString, details ) );
     }
 
-    void emitFinished()
-    {
-        QMetaObject::invokeMethod( m_queue, "finished", Qt::QueuedConnection );
-    }
+    void emitFinished() { QMetaObject::invokeMethod( m_queue, "finished", Qt::QueuedConnection ); }
 };
 
-JobThread::~JobThread()
-{
-}
+JobThread::~JobThread() {}
 
 
 JobQueue* JobQueue::s_instance = nullptr;
@@ -160,8 +180,10 @@ JobQueue::~JobQueue()
     if ( m_thread->isRunning() )
     {
         m_thread->terminate();
-        if ( !m_thread->wait(300) )
+        if ( !m_thread->wait( 300 ) )
+        {
             cError() << "Could not terminate job thread (expect a crash now).";
+        }
         delete m_thread;
     }
 
@@ -173,7 +195,7 @@ void
 JobQueue::start()
 {
     Q_ASSERT( !m_thread->isRunning() );
-    m_thread->setJobs( m_jobs );
+    m_thread->setJobs( std::move( m_jobs ) );
     m_jobs.clear();
     m_thread->start();
 }
@@ -196,4 +218,4 @@ JobQueue::enqueue( const JobList& jobs )
     emit queueChanged( m_jobs );
 }
 
-} // namespace Calamares
+}  // namespace Calamares
