@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -117,53 +117,6 @@ System::instance()
 }
 
 
-int
-System::mount( const QString& devicePath,
-               const QString& mountPoint,
-               const QString& filesystemName,
-               const QString& options )
-{
-    if ( devicePath.isEmpty() || mountPoint.isEmpty() )
-    {
-        if ( devicePath.isEmpty() )
-        {
-            cWarning() << "Can't mount an empty device.";
-        }
-        if ( mountPoint.isEmpty() )
-        {
-            cWarning() << "Can't mount on an empty mountpoint.";
-        }
-
-        return static_cast< int >( ProcessResult::Code::NoWorkingDirectory );
-    }
-
-    QDir mountPointDir( mountPoint );
-    if ( !mountPointDir.exists() )
-    {
-        bool ok = mountPointDir.mkpath( mountPoint );
-        if ( !ok )
-        {
-            cWarning() << "Could not create mountpoint" << mountPoint;
-            return static_cast< int >( ProcessResult::Code::NoWorkingDirectory );
-        }
-    }
-
-    QString program( "mount" );
-    QStringList args = { devicePath, mountPoint };
-
-    if ( !filesystemName.isEmpty() )
-    {
-        args << "-t" << filesystemName;
-    }
-
-    if ( !options.isEmpty() )
-    {
-        args << "-o" << options;
-    }
-
-    return QProcess::execute( program, args );
-}
-
 ProcessResult
 System::runCommand( System::RunLocation location,
                     const QStringList& args,
@@ -236,8 +189,9 @@ System::runCommand( System::RunLocation location,
     }
     process.closeWriteChannel();
 
-    if ( !process.waitForFinished(
-             timeoutSec > std::chrono::seconds::zero() ? ( std::chrono::milliseconds( timeoutSec ).count() ) : -1 ) )
+    if ( !process.waitForFinished( timeoutSec > std::chrono::seconds::zero()
+                                       ? ( static_cast< int >( std::chrono::milliseconds( timeoutSec ).count() ) )
+                                       : -1 ) )
     {
         cWarning().noquote().nospace() << "Timed out. Output so far:\n" << process.readAllStandardOutput();
         return ProcessResult::Code::TimedOut;
@@ -262,11 +216,16 @@ System::runCommand( System::RunLocation location,
     return ProcessResult( r, output );
 }
 
+/// @brief Cheap check if a path is absolute.
+static inline bool
+isAbsolutePath( const QString& path )
+{
+    return path.startsWith( '/' );
+}
+
 QString
 System::targetPath( const QString& path ) const
 {
-    QString completePath;
-
     if ( doChroot() )
     {
         Calamares::GlobalStorage* gs
@@ -274,33 +233,32 @@ System::targetPath( const QString& path ) const
 
         if ( !gs || !gs->contains( "rootMountPoint" ) )
         {
-            cWarning() << "No rootMountPoint in global storage, cannot create target file" << path;
+            cWarning() << "No rootMountPoint in global storage, cannot name target file" << path;
             return QString();
         }
 
-        completePath = gs->value( "rootMountPoint" ).toString() + '/' + path;
+        QString root = gs->value( "rootMountPoint" ).toString();
+        return isAbsolutePath( path ) ? ( root + path ) : ( root + '/' + path );
     }
     else
     {
-        completePath = QStringLiteral( "/" ) + path;
+        return isAbsolutePath( path ) ? path : ( QStringLiteral( "/" ) + path );
     }
-
-    return completePath;
 }
 
-QString
+CreationResult
 System::createTargetFile( const QString& path, const QByteArray& contents ) const
 {
     QString completePath = targetPath( path );
     if ( completePath.isEmpty() )
     {
-        return QString();
+        return CreationResult( CreationResult::Code::Invalid );
     }
 
     QFile f( completePath );
     if ( f.exists() )
     {
-        return QString();
+        return CreationResult( CreationResult::Code::AlreadyExists );
     }
 
     QIODevice::OpenMode m =
@@ -312,18 +270,71 @@ System::createTargetFile( const QString& path, const QByteArray& contents ) cons
 
     if ( !f.open( m ) )
     {
-        return QString();
+        return CreationResult( CreationResult::Code::Failed );
     }
 
     if ( f.write( contents ) != contents.size() )
     {
         f.close();
         f.remove();
-        return QString();
+        return CreationResult( CreationResult::Code::Failed );
     }
 
     f.close();
-    return QFileInfo( f ).canonicalFilePath();
+    return CreationResult( QFileInfo( f ).canonicalFilePath() );
+}
+
+void
+System::removeTargetFile( const QString& path ) const
+{
+    if ( !isAbsolutePath( path ) )
+    {
+        cWarning() << "Will not remove non-absolute path" << path;
+        return;
+    }
+    QString target = targetPath( path );
+    if ( !target.isEmpty() )
+    {
+        QFile::remove( target );
+    }
+    // If it was empty, a warning was already printed
+}
+
+bool
+System::createTargetDirs( const QString& path ) const
+{
+    if ( !isAbsolutePath( path ) )
+    {
+        cWarning() << "Will not create basedirs for non-absolute path" << path;
+        return false;
+    }
+
+    QString target = targetPath( path );
+    if ( target.isEmpty() )
+    {
+        // If it was empty, a warning was already printed
+        return false;
+    }
+
+    QString root = Calamares::JobQueue::instance()->globalStorage()->value( "rootMountPoint" ).toString();
+    if ( root.isEmpty() )
+    {
+        return false;
+    }
+
+    QDir d( root );
+    if ( !d.exists() )
+    {
+        cWarning() << "Root mountpoint" << root << "does not exist.";
+        return false;
+    }
+    return d.mkpath( target );  // This re-does everything starting from the **host** /
+}
+
+bool
+System::createTargetParentDirs( const QString& filePath ) const
+{
+    return createTargetDirs( QFileInfo( filePath ).dir().path() );
 }
 
 
