@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, 2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
 #include <QPair>
 #include <QString>
 
+#include <chrono>
+
 namespace CalamaresUtils
 {
 class ProcessResult : public QPair< int, QString >
@@ -34,15 +36,21 @@ class ProcessResult : public QPair< int, QString >
 public:
     enum class Code : int
     {
-        Crashed = -1,        // Must match special return values from QProcess
+        Crashed = -1,  // Must match special return values from QProcess
         FailedToStart = -2,  // Must match special return values from QProcess
         NoWorkingDirectory = -3,
         TimedOut = -4
-    } ;
+    };
 
     /** @brief Implicit one-argument constructor has no output, only a return code */
-    ProcessResult( Code r ) : QPair< int, QString >( static_cast<int>(r), QString() ) {}
-    ProcessResult( int r, QString s ) : QPair< int, QString >( r, s ) {}
+    ProcessResult( Code r )
+        : QPair< int, QString >( static_cast< int >( r ), QString() )
+    {
+    }
+    ProcessResult( int r, QString s )
+        : QPair< int, QString >( r, s )
+    {
+    }
 
     int getExitCode() const { return first; }
     QString getOutput() const { return second; }
@@ -60,20 +68,56 @@ public:
      * @param timeout   Timeout passed to the process runner, for explaining
      *                  error code -4 (timeout).
      */
-    static Calamares::JobResult explainProcess( int errorCode, const QString& command, const QString& output, int timeout );
+    static Calamares::JobResult
+    explainProcess( int errorCode, const QString& command, const QString& output, std::chrono::seconds timeout );
 
     /// @brief Convenience wrapper for explainProcess()
-    inline Calamares::JobResult explainProcess( const QString& command, int timeout ) const
+    inline Calamares::JobResult explainProcess( const QString& command, std::chrono::seconds timeout ) const
     {
         return explainProcess( getExitCode(), command, getOutput(), timeout );
     }
 
     /// @brief Convenience wrapper for explainProcess()
-    inline Calamares::JobResult explainProcess( const QStringList& command, int timeout ) const
+    inline Calamares::JobResult explainProcess( const QStringList& command, std::chrono::seconds timeout ) const
     {
         return explainProcess( getExitCode(), command.join( ' ' ), getOutput(), timeout );
     }
-} ;
+};
+
+/** @brief The result of a create*() action, for status
+ *
+ * A CreationResult has a status field, can be converted to bool
+ * (true only on success) and can report the full pathname of
+ * the thing created if it was successful.
+ */
+class CreationResult : public QPair< int, QString >
+{
+public:
+    enum class Code : int
+    {
+        // These are "not failed", but only OK is a success
+        OK = 0,
+        AlreadyExists = 1,
+        // These are "failed"
+        Invalid = -1,
+        Failed = -2
+    };
+
+    CreationResult( Code r )
+        : QPair< int, QString >( static_cast< int >( r ), QString() )
+    {
+    }
+    explicit CreationResult( const QString& path )
+        : QPair< int, QString >( 0, path )
+    {
+    }
+
+    Code code() const { return static_cast< Code >( first ); }
+    QString path() const { return second; }
+
+    bool failed() const { return first < 0; }
+    operator bool() const { return first == 0; }
+};
 
 /**
  * @brief The System class is a singleton with utility functions that perform
@@ -94,27 +138,14 @@ public:
 
     static System* instance();
 
-    /**
-      * Runs the mount utility with the specified parameters.
-      * @param devicePath the path of the partition to mount.
-      * @param mountPoint the full path of the target mount point.
-      * @param filesystemName the name of the filesystem (optional).
-      * @param options any additional options as passed to mount -o (optional).
-      * @returns the program's exit code, or:
-      *             Crashed = QProcess crash
-      *             FailedToStart = QProcess cannot start
-      *             NoWorkingDirectory = bad arguments
-      */
-    DLLEXPORT int mount( const QString& devicePath,
-                         const QString& mountPoint,
-                         const QString& filesystemName = QString(),
-                         const QString& options = QString() );
-
-
     /** (Typed) Boolean describing where a particular command should be run,
      *  whether in the host (live) system or in the (chroot) target system.
      */
-    enum class RunLocation { RunInHost, RunInTarget };
+    enum class RunLocation
+    {
+        RunInHost,
+        RunInTarget
+    };
 
     /**
       * Runs the specified command in the chroot of the target system.
@@ -133,37 +164,41 @@ public:
       *             NoWorkingDirectory = bad arguments
       *             TimedOut = QProcess timeout
       */
-    static DLLEXPORT ProcessResult runCommand(
-        RunLocation location,
-        const QStringList &args,
-        const QString& workingPath = QString(),
-        const QString& stdInput = QString(),
-        int timeoutSec = 0 );
+    static DLLEXPORT ProcessResult runCommand( RunLocation location,
+                                               const QStringList& args,
+                                               const QString& workingPath = QString(),
+                                               const QString& stdInput = QString(),
+                                               std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) );
+
+    /** @brief Convenience wrapper for runCommand()
+     *
+     * Runs the given command-line @p args in the host in the current direcory
+     * with no input, and the given @p timeoutSec for completion.
+     */
+    static inline ProcessResult runCommand( const QStringList& args, std::chrono::seconds timeoutSec )
+    {
+        return runCommand( RunLocation::RunInHost, args, QString(), QString(), timeoutSec );
+    }
 
     /** @brief Convenience wrapper for runCommand().
      *  Runs the command in the location specified through the boolean
      *  doChroot(), which is what you usually want for running commands
      *  during installation.
       */
-    inline ProcessResult targetEnvCommand(
-        const QStringList &args,
-        const QString& workingPath = QString(),
-        const QString& stdInput = QString(),
-        int timeoutSec = 0 )
+    inline ProcessResult targetEnvCommand( const QStringList& args,
+                                           const QString& workingPath = QString(),
+                                           const QString& stdInput = QString(),
+                                           std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) )
     {
         return runCommand(
-            m_doChroot ? RunLocation::RunInTarget : RunLocation::RunInHost,
-            args,
-            workingPath,
-            stdInput,
-            timeoutSec );
+            m_doChroot ? RunLocation::RunInTarget : RunLocation::RunInHost, args, workingPath, stdInput, timeoutSec );
     }
 
     /** @brief Convenience wrapper for targetEnvCommand() which returns only the exit code */
     inline int targetEnvCall( const QStringList& args,
                               const QString& workingPath = QString(),
                               const QString& stdInput = QString(),
-                              int timeoutSec = 0 )
+                              std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) )
     {
         return targetEnvCommand( args, workingPath, stdInput, timeoutSec ).first;
     }
@@ -172,9 +207,9 @@ public:
     inline int targetEnvCall( const QString& command,
                               const QString& workingPath = QString(),
                               const QString& stdInput = QString(),
-                              int timeoutSec = 0 )
+                              std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) )
     {
-        return targetEnvCall( QStringList{ command }, workingPath, stdInput, timeoutSec );
+        return targetEnvCall( QStringList { command }, workingPath, stdInput, timeoutSec );
     }
 
     /** @brief Convenience wrapper for targetEnvCommand() which returns only the exit code
@@ -182,10 +217,10 @@ public:
      * Places the called program's output in the @p output string.
      */
     int targetEnvOutput( const QStringList& args,
-                                QString& output,
-                                const QString& workingPath = QString(),
-                                const QString& stdInput = QString(),
-                                int timeoutSec = 0 )
+                         QString& output,
+                         const QString& workingPath = QString(),
+                         const QString& stdInput = QString(),
+                         std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) )
     {
         auto r = targetEnvCommand( args, workingPath, stdInput, timeoutSec );
         output = r.second;
@@ -200,45 +235,72 @@ public:
                                 QString& output,
                                 const QString& workingPath = QString(),
                                 const QString& stdInput = QString(),
-                                int timeoutSec = 0 )
+                                std::chrono::seconds timeoutSec = std::chrono::seconds( 0 ) )
     {
-        return targetEnvOutput( QStringList{ command }, output, workingPath, stdInput, timeoutSec );
+        return targetEnvOutput( QStringList { command }, output, workingPath, stdInput, timeoutSec );
     }
 
-    
+
     /** @brief Gets a path to a file in the target system, from the host.
-     * 
+     *
      * @param path Path to the file; this is interpreted
      *      from the root of the target system (whatever that may be,
      *      but / in the chroot, or / in OEM modes).
-     * 
+     *
      * @return The complete path to the target file, from
      *      the root of the host system, or empty on failure.
-     * 
+     *
      * For instance, during installation where the target root is
      * mounted on /tmp/calamares-something, asking for targetPath("/etc/passwd")
      * will give you /tmp/calamares-something/etc/passwd.
-     * 
+     *
      * No attempt is made to canonicalize anything, since paths might not exist.
-     */ 
+     */
     DLLEXPORT QString targetPath( const QString& path ) const;
-    
+
     /** @brief Create a (small-ish) file in the target system.
-     * 
+     *
      * @param path Path to the file; this is interpreted
      *      from the root of the target system (whatever that may be,
      *      but / in the chroot, or / in OEM modes).
      * @param contents Actual content of the file.
-     * 
+     *
      * Will not overwrite files. Returns an empty string if the
      * target file already exists.
-     * 
+     *
      * @return The complete canonical path to the target file from the
      *      root of the host system, or empty on failure. (Here, it is
      *      possible to be canonical because the file exists).
      */
-    DLLEXPORT QString createTargetFile( const QString& path, const QByteArray& contents ) const;
-    
+    DLLEXPORT CreationResult createTargetFile( const QString& path, const QByteArray& contents ) const;
+
+    /** @brief Remove a file from the target system.
+     *
+     * @param path Path to the file; this is interpreted from the root
+     *      of the target system (@see targetPath()).
+     *
+     * Does no error checking to see if the target file was really removed.
+     */
+    DLLEXPORT void removeTargetFile( const QString& path ) const;
+
+    /** @brief Ensure that the directory @p path exists
+     *
+     * @param path a full pathname to a desired directory.
+     *
+     * All the directory components including the last path component are
+     * created, as needed. Returns true on success.
+     *
+     * @see QDir::mkpath
+     */
+    DLLEXPORT bool createTargetDirs( const QString& path ) const;
+
+    /** @brief Convenience to create parent directories of a file path.
+     *
+     * Creates all the parent directories until the last
+     * component of @p filePath . @see createTargetDirs()
+     */
+    DLLEXPORT bool createTargetParentDirs( const QString& filePath ) const;
+
     /**
      * @brief getTotalMemoryB returns the total main memory, in bytes.
      *
@@ -253,7 +315,7 @@ public:
      *
      * @return size, guesstimate-factor
      */
-    DLLEXPORT QPair<quint64, float> getTotalMemoryB() const;
+    DLLEXPORT QPair< quint64, float > getTotalMemoryB() const;
 
     /**
      * @brief getCpuDescription returns a string describing the CPU.
@@ -277,6 +339,6 @@ private:
     bool m_doChroot;
 };
 
-}  // namespace
+}  // namespace CalamaresUtils
 
 #endif
